Change detectors — skchange

Skip to main content
`Ctrl`+`K`

# Change detectors

## Base

`BaseChangeDetector`() | Base class for change detectors.

## Change detectors

`MovingWindow`([change_score, bandwidth, ...]) | Moving window algorithm for multiple changepoint detection.
`PELT`([cost, penalty_scale, min_segment_length]) | Pruned exact linear time changepoint detection.
`SeededBinarySegmentation`([change_score, ...]) | Seeded binary segmentation algorithm for multiple changepoint detection.